summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmtreeview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
commite69e8b1d09fb579316595b4e6a850e717358a8b1 (patch)
treea24fc20865f65772f530d16177520190594ffdd2 /kpovmodeler/pmtreeview.h
parenteecec9afb81fdebb0f22e9da22635874c403f854 (diff)
downloadtdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.tar.gz
tdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.zip
TQt4 port kdegraphics
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1237557 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpovmodeler/pmtreeview.h')
-rw-r--r--kpovmodeler/pmtreeview.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/kpovmodeler/pmtreeview.h b/kpovmodeler/pmtreeview.h
index ec4d9c1b..445b53fd 100644
--- a/kpovmodeler/pmtreeview.h
+++ b/kpovmodeler/pmtreeview.h
@@ -41,7 +41,7 @@ public:
/**
* Default constructor
*/
- PMTreeViewWidget( PMPart* pare, TQWidget* parent, const char* name = 0 );
+ PMTreeViewWidget( PMPart* pare, TQWidget* tqparent, const char* name = 0 );
/** */
virtual TQString viewType( ) const { return TQString( "treeview" ); }
@@ -52,16 +52,17 @@ public:
/**
* Widget that displays the scene as tree view
*/
-class PMTreeView : public QListView
+class PMTreeView : public TQListView
{
Q_OBJECT
+ TQ_OBJECT
friend class PMTreeViewItem;
public:
/**
* Creates a PMTreeView with parent and name that displays the
* document doc
*/
- PMTreeView( PMPart* part, TQWidget* parent = 0, const char* name = 0 );
+ PMTreeView( PMPart* part, TQWidget* tqparent = 0, const char* name = 0 );
/**
* Deletes the PMTreeView
*/
@@ -173,9 +174,9 @@ public:
virtual TQString viewType( ) const { return TQString( "treeview" ); }
virtual TQString description( ) const;
virtual TQString iconName( ) const { return TQString( "pmtreeview" ); }
- virtual PMViewBase* newInstance( TQWidget* parent, PMPart* part ) const
+ virtual PMViewBase* newInstance( TQWidget* tqparent, PMPart* part ) const
{
- return new PMTreeViewWidget( part, parent );
+ return new PMTreeViewWidget( part, tqparent );
}
};
@@ -52,16 +52,17 @@ public:
public:
/**
- * Creates a PMTreeView with parent and name that displays the
+ * Creates a PMTreeView with tqparent and name that displays the
* document doc
*/